@@ -21,7 +21,9 @@ static char SccsId[] = "%W%  %G%";
  *		{3} MVH removed isalpha test for file names	1  Jan 1991
  *		{4} MVH added + type switches and support	21 Jun 1991
  *		{5} Doug Mink add nimage			21 Oct 1994
- *		{5} Doug Mink add plane as synonym of nimage	18 Oct 1995
+ *		{6} Doug Mink add plane as synonym of nimage	18 Oct 1995
+ *		{7} Doug Mink add zf and zoom for zoom factor    2 Jan 1996
+ *		{8} Doug Mink close pipe if image display        9 Feb 1996
  *		{n} <who> -- <does what> -- <when>
  */
 
@@ -58,6 +60,7 @@ int parse_filename ( argc, argv, argi, got_name )
 {
   int i;
   int usage();
+  void close_imtool_connection();
 
   i = *argi;
   /* --- check for the filename as an unidentified string --- */
@@ -70,6 +73,9 @@ int parse_filename ( argc, argv, argi, got_name )
       img.filename = argv[i];
       *got_name |= CMD_FNAME;
     }
+    /* --- Close imtool pipe --- */
+    control.IRAF_in.open = 0;
+    control.IRAF_in.func = NULL;
     return( 1 );
   }
   /* --- check for filename as an identified string --- */
@@ -187,6 +193,8 @@ int parse_fileread ( argc, argv, argi, got_read )
      int *got_read;	/* status word (bit that there were read parameters) */
 {
   int i;
+  float zoom;
+  void set_tdisp();
 
   i = *argi;
   if( (strcmp(argv[i], "-sk") == 0) ||
@@ -229,6 +237,25 @@ int parse_fileread ( argc, argv, argi, got_read )
 	return( usage("display blocking", argc, argv, i-1, i) );
     }
 
+  } else if( (strcmp(argv[i], "-zf") == 0) ||
+	     (strcmp(argv[i], "-zoom") == 0) ) {
+
+    /* --- initial zoom factor --- */
+    if( (++i >= argc) || ((zoom = atof(argv[i])) <= 0) )
+      return( usage("zoom factor", argc, argv, i-1, i) );
+
+    /* check against the limits before proceeding */
+    if( (0.01 > zoom) || (zoom > 400.0) ) {
+      (void)fprintf(stderr, "WARNING: Attempt to exceed zooming limits!\n");
+      img.zoom = 0.0;
+    }
+
+     /* tid.zoom = zoom but force exact integer alignment (int or 1/int) */
+    else if( zoom > 0.75 )
+      img.zoom = (double)((int)(zoom + 0.5));
+    else
+      img.zoom = 1.0 / (double)((int)((1.0 / zoom) + 0.5));
+
   } else if( (strcmp(argv[i], "-nim") == 0) ||
 	     (strcmp(argv[i], "-nimage") == 0) ||
 	     (strcmp(argv[i], "-plane") == 0) ) {
