@@ -6,6 +6,7 @@ static char SccsImageId[] = "%W%  %G%";
  * Purpose:	Define the struct for image reading & manipulation parameters
  * Modified:	{0} Michael VanHilst	initial version	      24 January 1989
  * Modified:	{1} Doug Mink     move WCS info to wcs.h      18 October 1995
+ * Modified:	{2} Doug Mink     add initial zoom factor      2 January 1996
  *		{n} <who> -- <does what> -- <when>
  */
 
@@ -55,4 +56,5 @@ struct imageRec {
   int frame_number;		/* imtool frame number */
   int imtool_200;		/* current image is from imtool */
   int panbox_zoomtype;		/* type of zoom from image (av, max, sample) */
+  double zoom;			/* zoom factor */
 };
