@@ -5,6 +5,7 @@ static char SccsStructId[] = "%W%  %G%";
 /* Module:	Struct.h
  * Purpose:	Declare all of the major structure types
  * Modified:	{0} Michael VanHilst	initial version		  5 June 1989
+ *		{1} Doug Mink           added wcs                 6 July 1995
  *		{n} <who> -- <does what> -- <when>
  */
 
@@ -15,3 +16,4 @@ static char SccsStructId[] = "%W%  %G%";
 #include "image.h"
 #include "window.h"
 #include "buffer.h"
+#include "wcs.h"
