@@ -3,9 +3,9 @@
 /* point button: CursorA1 */
 #define CursorA1_offo_width 6
 #define CursorA1_offo_height 6
-static char CursorA1_offo_label[] = {
+static unsigned char CursorA1_offo_label[] = {
   0x00, 0x00, 0x0c, 0x0c, 0x00, 0x00 };
-static char CursorA1_offo_mask[] = {
+static unsigned char CursorA1_offo_mask[] = {
   0x1e, 0x3f, 0x3f, 0x3f, 0x3f, 0x1e };
 static ButtonLabel CursorA1_offo = {
   (unsigned char *)CursorA1_offo_label, (unsigned char *)CursorA1_offo_mask,
@@ -14,9 +14,9 @@ static ButtonLabel CursorA1_offo = {
   1, 0, 0, NULL };
 #define CursorA1_offi_width 6
 #define CursorA1_offi_height 6
-static char CursorA1_offi_label[] = {
+static unsigned char CursorA1_offi_label[] = {
   0x00, 0x0c, 0x1e, 0x1e, 0x0c, 0x00 };
-static char CursorA1_offi_mask[] = {
+static unsigned char CursorA1_offi_mask[] = {
   0x1e, 0x3f, 0x3f, 0x3f, 0x3f, 0x1e };
 static ButtonLabel CursorA1_offi = {
   (unsigned char *)CursorA1_offi_label, (unsigned char *)CursorA1_offi_mask,
@@ -35,11 +35,11 @@ static ButtonFeel CursorA1_feel = {
 /* poly button: CursorA2 */
 #define CursorA2_offo_width 21
 #define CursorA2_offo_height 11
-static char CursorA2_offo_label[] = {
+static unsigned char CursorA2_offo_label[] = {
   0x00, 0x00, 0x00, 0x02, 0x02, 0x08, 0x06, 0x05, 0x0c, 0x8a, 0x08, 0x0a,
   0x52, 0x10, 0x09, 0x22, 0xa0, 0x08, 0x02, 0x40, 0x08, 0x02, 0x00, 0x08,
   0x02, 0x00, 0x08, 0xfe, 0xff, 0x0f, 0x00, 0x00, 0x00 };
-static char CursorA2_offo_mask[] = {
+static unsigned char CursorA2_offo_mask[] = {
   0x07, 0x07, 0x1c, 0x8f, 0x0f, 0x1e, 0xdf, 0x1f, 0x1f, 0xff, 0xbf, 0x1f,
   0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f, 0xff, 0xfd, 0x1f, 0xff, 0xff, 0x1f,
   0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f };
@@ -50,11 +50,11 @@ static ButtonLabel CursorA2_offo = {
   3, 0, 0, NULL };
 #define CursorA2_offi_width 21
 #define CursorA2_offi_height 11
-static char CursorA2_offi_label[] = {
+static unsigned char CursorA2_offi_label[] = {
   0x00, 0x00, 0x00, 0x02, 0x02, 0x08, 0x06, 0x07, 0x0c, 0x8e, 0x0f, 0x0e,
   0xde, 0x1d, 0x0f, 0xfe, 0xb8, 0x0f, 0x76, 0xf0, 0x0d, 0x06, 0xe0, 0x0c,
   0xfe, 0xff, 0x0f, 0xfe, 0xff, 0x0f, 0x00, 0x00, 0x00 };
-static char CursorA2_offi_mask[] = {
+static unsigned char CursorA2_offi_mask[] = {
   0x07, 0x07, 0x1c, 0x8f, 0x0f, 0x1e, 0xdf, 0x1f, 0x1f, 0xff, 0xbf, 0x1f,
   0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f, 0xff, 0xfd, 0x1f, 0xff, 0xff, 0x1f,
   0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f };
@@ -75,11 +75,11 @@ static ButtonFeel CursorA2_feel = {
 /* circle button: CursorA3 */
 #define CursorA3_offo_width 15
 #define CursorA3_offo_height 15
-static char CursorA3_offo_label[] = {
+static unsigned char CursorA3_offo_label[] = {
   0x00, 0x00, 0xe0, 0x03, 0x18, 0x0c, 0x04, 0x10, 0x04, 0x10, 0x02, 0x20,
   0x02, 0x20, 0x02, 0x20, 0x02, 0x20, 0x02, 0x20, 0x04, 0x10, 0x04, 0x10,
   0x18, 0x0c, 0xe0, 0x03, 0x00, 0x00 };
-static char CursorA3_offo_mask[] = {
+static unsigned char CursorA3_offo_mask[] = {
   0xf0, 0x07, 0xfc, 0x1f, 0xfe, 0x3f, 0xfe, 0x3f, 0x3f, 0x7e, 0x1f, 0x7c,
   0x0f, 0x78, 0x0f, 0x78, 0x0f, 0x78, 0x1f, 0x7c, 0x3f, 0x7e, 0xfe, 0x3f,
   0xfe, 0x3f, 0xfc, 0x1f, 0xf0, 0x07 };
@@ -90,11 +90,11 @@ static ButtonLabel CursorA3_offo = {
   2, 0, 0, NULL };
 #define CursorA3_offi_width 15
 #define CursorA3_offi_height 15
-static char CursorA3_offi_label[] = {
+static unsigned char CursorA3_offi_label[] = {
   0x00, 0x00, 0xe0, 0x03, 0xf8, 0x0f, 0x1c, 0x1c, 0x0c, 0x18, 0x06, 0x30,
   0x06, 0x30, 0x06, 0x30, 0x06, 0x30, 0x06, 0x30, 0x0c, 0x18, 0x1c, 0x1c,
   0xf8, 0x0f, 0xe0, 0x03, 0x00, 0x00 };
-static char CursorA3_offi_mask[] = {
+static unsigned char CursorA3_offi_mask[] = {
   0xf0, 0x07, 0xfc, 0x1f, 0xfe, 0x3f, 0xfe, 0x3f, 0x3f, 0x7e, 0x1f, 0x7c,
   0x0f, 0x78, 0x0f, 0x78, 0x0f, 0x78, 0x1f, 0x7c, 0x3f, 0x7e, 0xfe, 0x3f,
   0xfe, 0x3f, 0xfc, 0x1f, 0xf0, 0x07 };
@@ -115,11 +115,11 @@ static ButtonFeel CursorA3_feel = {
 /* ellipse button: CursorA4 */
 #define CursorA4_offo_width 23
 #define CursorA4_offo_height 11
-static char CursorA4_offo_label[] = {
+static unsigned char CursorA4_offo_label[] = {
   0x00, 0x00, 0x00, 0x80, 0xff, 0x00, 0x70, 0x00, 0x07, 0x0c, 0x00, 0x18,
   0x02, 0x00, 0x20, 0x02, 0x00, 0x20, 0x02, 0x00, 0x20, 0x0c, 0x00, 0x18,
   0x70, 0x00, 0x07, 0x80, 0xff, 0x00, 0x00, 0x00, 0x00 };
-static char CursorA4_offo_mask[] = {
+static unsigned char CursorA4_offo_mask[] = {
   0xc0, 0xff, 0x01, 0xf8, 0xff, 0x0f, 0xfe, 0xff, 0x3f, 0xff, 0xff, 0x7f,
   0xff, 0x80, 0x7f, 0x1f, 0x00, 0x7c, 0xff, 0x80, 0x7f, 0xff, 0xff, 0x7f,
   0xfe, 0xff, 0x3f, 0xf8, 0xff, 0x0f, 0xc0, 0xff, 0x01 };
@@ -130,11 +130,11 @@ static ButtonLabel CursorA4_offo = {
   3, 0, 0, NULL };
 #define CursorA4_offi_width 23
 #define CursorA4_offi_height 11
-static char CursorA4_offi_label[] = {
+static unsigned char CursorA4_offi_label[] = {
   0x00, 0x00, 0x00, 0x80, 0xff, 0x00, 0xf0, 0xff, 0x07, 0x7c, 0x00, 0x1f,
   0x0e, 0x00, 0x38, 0x06, 0x00, 0x30, 0x0e, 0x00, 0x38, 0x7c, 0x00, 0x1f,
   0xf0, 0xff, 0x07, 0x80, 0xff, 0x00, 0x00, 0x00, 0x00 };
-static char CursorA4_offi_mask[] = {
+static unsigned char CursorA4_offi_mask[] = {
   0xc0, 0xff, 0x01, 0xf8, 0xff, 0x0f, 0xfe, 0xff, 0x3f, 0xff, 0xff, 0x7f,
   0xff, 0x80, 0x7f, 0x1f, 0x00, 0x7c, 0xff, 0x80, 0x7f, 0xff, 0xff, 0x7f,
   0xfe, 0xff, 0x3f, 0xf8, 0xff, 0x0f, 0xc0, 0xff, 0x01 };
@@ -155,11 +155,11 @@ static ButtonFeel CursorA4_feel = {
 /* box button: CursorA5 */
 #define CursorA5_offo_width 21
 #define CursorA5_offo_height 11
-static char CursorA5_offo_label[] = {
+static unsigned char CursorA5_offo_label[] = {
   0x00, 0x00, 0x00, 0xfe, 0xff, 0x0f, 0x02, 0x00, 0x08, 0x02, 0x00, 0x08,
   0x02, 0x00, 0x08, 0x02, 0x00, 0x08, 0x02, 0x00, 0x08, 0x02, 0x00, 0x08,
   0x02, 0x00, 0x08, 0xfe, 0xff, 0x0f, 0x00, 0x00, 0x00 };
-static char CursorA5_offo_mask[] = {
+static unsigned char CursorA5_offo_mask[] = {
   0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f,
   0x0f, 0x00, 0x1e, 0x0f, 0x00, 0x1e, 0x0f, 0x00, 0x1e, 0xff, 0xff, 0x1f,
   0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f };
@@ -170,11 +170,11 @@ static ButtonLabel CursorA5_offo = {
   3, 0, 0, NULL };
 #define CursorA5_offi_width 21
 #define CursorA5_offi_height 11
-static char CursorA5_offi_label[] = {
+static unsigned char CursorA5_offi_label[] = {
   0x00, 0x00, 0x00, 0xfe, 0xff, 0x0f, 0xfe, 0xff, 0x0f, 0x06, 0x00, 0x0c,
   0x06, 0x00, 0x0c, 0x06, 0x00, 0x0c, 0x06, 0x00, 0x0c, 0x06, 0x00, 0x0c,
   0xfe, 0xff, 0x0f, 0xfe, 0xff, 0x0f, 0x00, 0x00, 0x00 };
-static char CursorA5_offi_mask[] = {
+static unsigned char CursorA5_offi_mask[] = {
   0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f,
   0x0f, 0x00, 0x1e, 0x0f, 0x00, 0x1e, 0x0f, 0x00, 0x1e, 0xff, 0xff, 0x1f,
   0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f, 0xff, 0xff, 0x1f };
@@ -195,10 +195,10 @@ static ButtonFeel CursorA5_feel = {
 /* ortho button: CursorA6 */
 #define CursorA6_offo_width 15
 #define CursorA6_offo_height 12
-static char CursorA6_offo_label[] = {
+static unsigned char CursorA6_offo_label[] = {
   0x00, 0x00, 0x38, 0x1c, 0x44, 0x22, 0x82, 0x22, 0x82, 0x22, 0x82, 0x1c,
   0x82, 0x00, 0x82, 0x00, 0x82, 0x00, 0x44, 0x00, 0x38, 0x00, 0x00, 0x00 };
-static char CursorA6_offo_mask[] = {
+static unsigned char CursorA6_offo_mask[] = {
   0x7c, 0x3e, 0xfe, 0x7f, 0xff, 0x7f, 0xff, 0x7f, 0xef, 0x7f, 0xef, 0x7f,
   0xef, 0x3f, 0xef, 0x01, 0xff, 0x01, 0xff, 0x01, 0xfe, 0x00, 0x7c, 0x00 };
 static ButtonLabel CursorA6_offo = {
@@ -208,10 +208,10 @@ static ButtonLabel CursorA6_offo = {
   2, 0, 0, NULL };
 #define CursorA6_offi_width 15
 #define CursorA6_offi_height 12
-static char CursorA6_offi_label[] = {
+static unsigned char CursorA6_offi_label[] = {
   0x00, 0x00, 0x38, 0x1c, 0x6c, 0x36, 0xc6, 0x36, 0xc6, 0x36, 0xc6, 0x1c,
   0xc6, 0x00, 0xc6, 0x00, 0xc6, 0x00, 0x6c, 0x00, 0x38, 0x00, 0x00, 0x00 };
-static char CursorA6_offi_mask[] = {
+static unsigned char CursorA6_offi_mask[] = {
   0x7c, 0x3e, 0xfe, 0x7f, 0xff, 0x7f, 0xff, 0x7f, 0xef, 0x7f, 0xef, 0x7f,
   0xef, 0x3f, 0xef, 0x01, 0xff, 0x01, 0xff, 0x01, 0xfe, 0x00, 0x7c, 0x00 };
 static ButtonLabel CursorA6_offi = {
@@ -231,11 +231,11 @@ static ButtonFeel CursorA6_feel = {
 /* annuli button: CursorA7 */
 #define CursorA7_offo_width 15
 #define CursorA7_offo_height 15
-static char CursorA7_offo_label[] = {
+static unsigned char CursorA7_offo_label[] = {
   0x00, 0x00, 0xfe, 0x3f, 0x02, 0x20, 0x02, 0x20, 0xf2, 0x27, 0x12, 0x24,
   0x12, 0x24, 0x12, 0x24, 0x12, 0x24, 0x12, 0x24, 0xf2, 0x27, 0x02, 0x20,
   0x02, 0x20, 0xfe, 0x3f, 0x00, 0x00 };
-static char CursorA7_offo_mask[] = {
+static unsigned char CursorA7_offo_mask[] = {
   0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f,
   0xff, 0x7f, 0x7f, 0x7f, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f,
   0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f };
@@ -246,11 +246,11 @@ static ButtonLabel CursorA7_offo = {
   2, 0, 0, NULL };
 #define CursorA7_offi_width 15
 #define CursorA7_offi_height 15
-static char CursorA7_offi_label[] = {
+static unsigned char CursorA7_offi_label[] = {
   0x00, 0x00, 0xfe, 0x3f, 0xfe, 0x3f, 0x06, 0x30, 0xf6, 0x37, 0xf6, 0x37,
   0x36, 0x36, 0x36, 0x36, 0x36, 0x36, 0xf6, 0x37, 0xf6, 0x37, 0x06, 0x30,
   0xfe, 0x3f, 0xfe, 0x3f, 0x00, 0x00 };
-static char CursorA7_offi_mask[] = {
+static unsigned char CursorA7_offi_mask[] = {
   0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f,
   0xff, 0x7f, 0x7f, 0x7f, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f,
   0xff, 0x7f, 0xff, 0x7f, 0xff, 0x7f };
@@ -271,10 +271,10 @@ static ButtonFeel CursorA7_feel = {
 /* arrow button: CursorA8 */
 #define CursorA8_offo_width 16
 #define CursorA8_offo_height 9
-static char CursorA8_offo_label[] = {
+static unsigned char CursorA8_offo_label[] = {
   0x00, 0x00, 0x80, 0x01, 0x60, 0x00, 0x18, 0x00, 0xfe, 0x7f, 0x18, 0x00,
   0x60, 0x00, 0x80, 0x01, 0x00, 0x00 };
-static char CursorA8_offo_mask[] = {
+static unsigned char CursorA8_offo_mask[] = {
   0xc0, 0x03, 0xf0, 0x03, 0xfc, 0x03, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xfc, 0x03, 0xf0, 0x03, 0xc0, 0x03 };
 static ButtonLabel CursorA8_offo = {
@@ -284,10 +284,10 @@ static ButtonLabel CursorA8_offo = {
   2, 0, 0, NULL };
 #define CursorA8_offi_width 16
 #define CursorA8_offi_height 9
-static char CursorA8_offi_label[] = {
+static unsigned char CursorA8_offi_label[] = {
   0x00, 0x00, 0x80, 0x01, 0xe0, 0x01, 0xf8, 0x00, 0xfe, 0x7f, 0xf8, 0x00,
   0xe0, 0x01, 0x80, 0x01, 0x00, 0x00 };
-static char CursorA8_offi_mask[] = {
+static unsigned char CursorA8_offi_mask[] = {
   0xc0, 0x03, 0xf0, 0x03, 0xfc, 0x03, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
   0xfc, 0x03, 0xf0, 0x03, 0xc0, 0x03 };
 static ButtonLabel CursorA8_offi = {
@@ -307,12 +307,12 @@ static ButtonFeel CursorA8_feel = {
 /* abc button: CursorA9 */
 #define CursorA9_offo_width 24
 #define CursorA9_offo_height 14
-static char CursorA9_offo_label[] = {
+static unsigned char CursorA9_offo_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x02, 0x00, 0x00, 0x02, 0x00, 0x00, 0x02, 0x00,
   0x1c, 0x1a, 0x38, 0x22, 0x26, 0x44, 0x30, 0x42, 0x02, 0x2c, 0x42, 0x02,
   0x22, 0x42, 0x02, 0x22, 0x26, 0x44, 0x5c, 0x1a, 0x38, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
-static char CursorA9_offo_mask[] = {
+static unsigned char CursorA9_offo_mask[] = {
   0x00, 0x07, 0x00, 0x00, 0x07, 0x00, 0x00, 0x07, 0x00, 0x3e, 0x3f, 0x7c,
   0x7f, 0x7f, 0xfe, 0x7f, 0xff, 0xff, 0x7f, 0xff, 0xef, 0x7f, 0xe7, 0x07,
   0x7f, 0xff, 0xef, 0xff, 0xff, 0xff, 0xff, 0x7f, 0xfe, 0xfe, 0x3f, 0x7c,
@@ -325,12 +325,12 @@ static ButtonLabel CursorA9_offo = {
   3, 3, 0, CursorA9_offo_breaks };
 #define CursorA9_offi_width 24
 #define CursorA9_offi_height 14
-static char CursorA9_offi_label[] = {
+static unsigned char CursorA9_offi_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x03, 0x00, 0x00, 0x03, 0x00, 0x00, 0x03, 0x00,
   0x1e, 0x3f, 0x3e, 0x33, 0x63, 0x63, 0x30, 0x63, 0x03, 0x3e, 0x63, 0x03,
   0x33, 0x63, 0x63, 0x33, 0x63, 0x63, 0x6e, 0x3f, 0x3e, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00 };
-static char CursorA9_offi_mask[] = {
+static unsigned char CursorA9_offi_mask[] = {
   0x80, 0x07, 0x00, 0x80, 0x07, 0x00, 0x80, 0x07, 0x00, 0xbf, 0x7f, 0x7f,
   0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf7, 0xf7, 0xff, 0xf7, 0xf7,
   0xff, 0xf7, 0xf7, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x7f, 0x7f,
@@ -366,7 +366,7 @@ static BoxGeometry CursorA_geo =
 /* region button: CursorB10 */
 #define CursorB10_offo_width 42
 #define CursorB10_offo_height 14
-static char CursorB10_offo_label[] = {
+static unsigned char CursorB10_offo_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00,
   0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x1a, 0x06, 0x96, 0x70, 0xe8, 0x00, 0x06, 0x09, 0x99, 0x88, 0x18, 0x01,
@@ -374,7 +374,7 @@ static char CursorB10_offo_label[] = {
   0x82, 0x80, 0x90, 0x04, 0x09, 0x01, 0x02, 0x11, 0x99, 0x88, 0x08, 0x01,
   0x02, 0x0e, 0x96, 0x70, 0x08, 0x01, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00,
   0x00, 0x80, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0f, 0x00, 0x00, 0x00 };
-static char CursorB10_offo_mask[] = {
+static unsigned char CursorB10_offo_mask[] = {
   0x00, 0x00, 0xc0, 0x01, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x01, 0x00, 0x00,
   0x00, 0x00, 0xc0, 0x01, 0x00, 0x00, 0x3f, 0x0f, 0xff, 0xf9, 0xfc, 0x01,
   0xbf, 0x9f, 0xff, 0xfd, 0xfd, 0x03, 0xff, 0xff, 0xff, 0xff, 0xff, 0x03,
@@ -390,7 +390,7 @@ static ButtonLabel CursorB10_offo = {
   6, 6, 0, CursorB10_offo_breaks };
 #define CursorB10_offi_width 41
 #define CursorB10_offi_height 14
-static char CursorB10_offi_label[] = {
+static unsigned char CursorB10_offi_label[] = {
   0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0x00, 0x00, 0x00,
   0x00, 0x00, 0xc0, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
   0x9f, 0x8f, 0xdf, 0x7c, 0x7e, 0x00, 0xdb, 0xd8, 0xd8, 0xc6, 0xc6, 0x00,
@@ -398,7 +398,7 @@ static char CursorB10_offi_label[] = {
   0xc3, 0xc0, 0xd8, 0xc6, 0xc6, 0x00, 0xc3, 0xd8, 0xd8, 0xc6, 0xc6, 0x00,
   0x83, 0x8f, 0xdf, 0x7c, 0xc6, 0x00, 0x00, 0x00, 0x18, 0x00, 0x00, 0x00,
   0x00, 0xc0, 0x18, 0x00, 0x00, 0x00, 0x00, 0x80, 0x0f, 0x00, 0x00, 0x00 };
-static char CursorB10_offi_mask[] = {
+static unsigned char CursorB10_offi_mask[] = {
   0x00, 0x00, 0xe0, 0x01, 0x00, 0x00, 0x00, 0x00, 0xe0, 0x01, 0x00, 0x00,
   0x00, 0x00, 0xe0, 0x01, 0x00, 0x00, 0xff, 0xdf, 0xff, 0xff, 0xff, 0x00,
   0xff, 0xff, 0xff, 0xff, 0xff, 0x01, 0xff, 0xff, 0xff, 0xff, 0xff, 0x01,
