@@ -31,7 +31,7 @@ static char SccsId[] = "%W%  %G%";
 /* root window dimensions in wndwinit.c */
 extern int screen_width, screen_height;
 
-static double ip_zoom;
+static double ip_zoomX, ip_zoomY;
 static int pan_xwidth, pan_yheight;
 /*
  * Subroutine:	init_panbox_dimensions
@@ -42,38 +42,54 @@ static int pan_xwidth, pan_yheight;
 void init_panbox_dimensions ( )
 {
   int xzoom, yzoom;
+  double ip_zoom;
 
-  /* calculate the drawing area for the given window size */
+  /* Calculate the drawing area for the given window size */
   pan_xwidth = panbox.hints.max_width - (2 * panbox.xzero);
   pan_yheight = panbox.hints.max_height - (2 * panbox.yzero);
-  /* select a zoom factor which fits image within pan window */
+
+  /* Select a zoom factor which fits image within pan window */
   xzoom = (coord.img.width - 1) / pan_xwidth + 1;
   yzoom = (coord.img.height - 1) / pan_yheight + 1;
+
+  /* Big image rule: zoom for which one dimension is window size or less */
   if( (xzoom > 1) || (yzoom > 1) ) {
-    /* big image rule: zoom for which one dimension is window size or less */
     ip_zoom = 1.0 / (double)MAX(xzoom,yzoom);
+
+  /* Small image rule: zoom for which one side is greater than 1/2 window */
   } else {
-    /* small image rule: zoom for which one side is greater than 1/2 window */
     xzoom = pan_xwidth / coord.img.width;
     yzoom = pan_yheight / coord.img.height;
     ip_zoom = (double)MIN(xzoom,yzoom);
   }
-  /* specify pan window size for perfect fit to zoomed img */
+
+  /* Specify pan window size for perfect fit to zoomed img */
   pan_xwidth = (int)((double)coord.img.width * ip_zoom);
+  if (pan_xwidth < 1) {
+    pan_xwidth = coord.img.width;
+    ip_zoomX = 1.0;
+    }
+  else
+    ip_zoomX = ip_zoom;
+
   pan_yheight = (int)((double)coord.img.height * ip_zoom);
+  if (pan_yheight < 1) {
+    pan_yheight = coord.img.height;
+    ip_zoomY = 1.0;
+    }
+  else
+    ip_zoomY = ip_zoom;
   panbox.hints.width = pan_xwidth + (2 * panbox.xzero);
-  /* if (panbox.hints.width < panbox.hints.min_width)
-      panbox.hints.width = panbox.hints.min_width; */
   panbox.hints.height = pan_yheight + (2 * panbox.yzero);
-  /* if (panbox.hints.height < panbox.hints.min_height)
-      panbox.hints.height = panbox.hints.min_height; */
-  /* aspect ratio may put one side below minimum */
+
+  /* Aspect ratio may put one side below minimum */
   if (panbox.hints.width > 0 &&
       panbox.hints.min_width > panbox.hints.width )
     panbox.hints.min_width = panbox.hints.width;
   if (panbox.hints.height > 0 &&
       panbox.hints.min_height > panbox.hints.height )
     panbox.hints.min_height = panbox.hints.height;
+
   /* set sizing guidlines to maintain image aspect ratio */
   panbox.hints.min_aspect.x = coord.img.width;
   panbox.hints.max_aspect.x = coord.img.width;
@@ -95,12 +111,14 @@ void init_panbox_coords ( )
   panbox.yzero = MAX(0, ((int)panbox.height - pan_yheight)/2);
   panbox.xwidth = pan_xwidth;
   panbox.yheight = pan_yheight;
+
   /* fill out pan window coordinate system parameters */
   set_coordsys(&coord.pan, 0.5, (int)panbox.width, (int)panbox.height,
 	       panbox.xzero, panbox.yzero, panbox.xzero + panbox.xwidth - 1,
 	       panbox.yzero + panbox.yheight - 1);
+
   /* compute coordinate conversions between pan and img systems */
-  set_transform(coord.img.cenX, coord.img.cenY, ip_zoom,
+  set_transform (coord.img.cenX, coord.img.cenY, ip_zoomX, ip_zoomY,
 		&coord.pan, &coord.img, &coord.pantoimg, &coord.imgtopan);
   combine_transform(&coord.pantofile, &coord.pantoimg, &coord.imgtofile);
   set_edges(&coord.pantofile, &coord.file, &coord.pan, &coord.fp);
