@@ -1,31 +1,31 @@
 /*** File wcscon.c
  *** Doug Mink, Harvard-Smithsonian Center for Astrophysics
  *** Based on Starlink subroutines by Patrick Wallace
- *** September 8, 1995
+ *** August 6, 1996
 
  * Module:	wcscon.c (World Coordinate System conversion)
  * Purpose:	Convert between various sky coordinate systems
  * Subroutine:	fk524 (ra,dec) Convert J2000(FK5) to B1950(FK4) coordinates
- * Subroutine:	fk524m (ra,dec,rapm,decpm)
+ * Subroutine:	fk524e (ra, dec, epoch) (more accurate for known position epoch
+ * Subroutine:	fk524m (ra,dec,rapm,decpm) exact
  * Subroutine:	fk425 (ra,dec) Convert B1950(FK4) to J2000(FK5) coordinates
- * Subroutine:	fk425m (ra, dec, rapm, decpm)
+ * Subroutine:	fk425e (ra, dec, epoch) (more accurate for known position epoch
+ * Subroutine:	fk425m (ra, dec, rapm, decpm) exact
  * Subroutine:	fk42gal (dtheta,dphi) Convert B1950(FK4) to galactic coordinates
  * Subroutine:	fk52gal (dtheta,dphi) Convert J2000(FK5) to galactic coordinates
  * Subroutine:	gal2fk4 (dtheta,dphi) Convert galactic coordinates to B1950(FK4)
  * Subroutine:	gal2fk5 (dtheta,dphi) Convert galactic coordinates to J2000<FK5)
-
- * Copyright:   1995 Smithsonian Astrophysical Observatory
- *              You may do anything you like with this file except remove
- *              this copyright.  The Smithsonian Astrophysical Observatory
- *              makes no representations about the suitability of this
- *              software for any purpose.  It is provided "as is" without
- *              express or implied warranty.
+ * Subroutine:  fk5prec (ep0, ep1, ra, dec) Precession ep0 to ep1, FK5 system
+ * Subroutine:  fk4prec (ep0, ep1, ra, dec) Precession ep0 to ep1, FK4 system
  */
 
 #include <math.h>
 #ifndef VMS
 #include <stdlib.h>
 #endif
+#include <ctype.h>
+#include <string.h>
+#include "wcs.h"
 
 /*  Constant vector and matrix (by columns)
     These values were obtained by inverting C.Hohenkerk's forward matrix
@@ -57,31 +57,57 @@ static double emi[6][6] = {
 	-0.000000011777422,  0.000000000065846, -0.000002424049954,
 	 0.004858519590501, -0.000027165866691,  0.999966838131419};
 
-void fk524 (ra,dec)
+void
+fk524 (ra,dec)
 
 double	*ra;		/* Right ascension in degrees (J2000 in, B1950 out) */
 double	*dec;		/* Declination in degrees (J2000 in, B1950 out) */
 
 {
-double	rra;		/* Right ascension in radians (J2000 in, B1950 out) */
-double	rdec;		/* Declination in radians (J2000 in, B1950 out) */
-double	rapm;		/* Proper motion in right ascension */
-double	decpm;		/* Proper motion in declination  */
+    double	rra;	/* Right ascension in radians (J2000 in, B1950 out) */
+    double	rdec;	/* Declination in radians (J2000 in, B1950 out) */
+    double	rapm;	/* Proper motion in right ascension */
+    double	decpm;	/* Proper motion in declination  */
 			/* In:  rad/jul.yr.  Out: rad/trop.yr.  */
-double	rcon = 1.74532925199433e-2; /* radians per degree */
-void	fk524m();
+    void	fk524m();
 
-	rra = *ra * rcon;
-	rdec = *dec * rcon;
-	rapm = (double) 0.0;
-	decpm = (double) 0.0;
-	fk524m (&rra, &rdec, &rapm, &decpm);
-	*ra = rra / rcon;
-	*dec = rdec / rcon;
-	return;
+    rra = degrad (*ra);
+    rdec = degrad (*dec);
+    rapm = (double) 0.0;
+    decpm = (double) 0.0;
+    fk524m (&rra, &rdec, &rapm, &decpm);
+    *ra = raddeg (rra);
+    *dec = raddeg (rdec);
+    return;
 }
 
-void fk524m (ra,dec,rapm,decpm)
+void
+fk524e (ra, dec, epoch)
+
+double	*ra;		/* Right ascension in degrees (J2000 in, B1950 out) */
+double	*dec;		/* Declination in degrees (J2000 in, B1950 out) */
+double	epoch;		/* Besselian epoch in years */
+
+{
+    double	rra;	/* Right ascension in radians (J2000 in, B1950 out) */
+    double	rdec;	/* Declination in radians (J2000 in, B1950 out) */
+    double	rapm;	/* Proper motion in right ascension */
+    double	decpm;	/* Proper motion in declination  */
+			/* In:  rad/jul.yr.  Out: rad/trop.yr.  */
+    void	fk524m();
+
+    rra = degrad (*ra);
+    rdec = degrad (*dec);
+    rapm = (double) 0.0;
+    decpm = (double) 0.0;
+    fk524m (&rra, &rdec, &rapm, &decpm);
+    *ra = raddeg (rra + (rapm * (epoch - 1950.0)));
+    *dec = raddeg (rdec + (decpm * (epoch - 1950.0)));
+    return;
+}
+
+void
+fk524m (ra,dec,rapm,decpm)
 
 double	*ra;		/* Right ascension in radians (J2000 in, B1950 out) */
 double	*dec;		/* Declination in radians (J2000 in, B1950 out) */
@@ -94,7 +120,7 @@ double	*decpm;		/* Proper motion in declination  */
     implementation (see ref 2) of a matrix method due to Standish
     (see ref 3).  The numerical values of ref 2 are used canonically.
 
-/*  Notes:
+ *  Notes:
 
       1)  The proper motions in ra are dra / dt rather than
  	    cos(dec) * dra / dt, and are per year rather than per century.
@@ -153,7 +179,6 @@ double	r1950,d1950;	/* B1950.0 ra,dec (rad) */
 double	dr1950,dd1950;	/* B1950.0 proper motions (rad/trop.yr) */
 
 /* Miscellaneous */
-
 double	ur,ud;
 double	sr,cr,sd,cd,x,y,z,w;
 double	v1[6],v2[6];
@@ -173,7 +198,6 @@ double	rcon = 1.74532925199433e-2; /* radians per degree */
 	pmf = 100. * 60. * 60. * 360. / d2pi;
 
 /* Pick up J2000 data (units radians and arcsec / jc) */
-
 	r2000 = *ra;
 	d2000 = *dec;
 	dr2000 = *rapm;
@@ -182,7 +206,6 @@ double	rcon = 1.74532925199433e-2; /* radians per degree */
 	ud = dd2000 * pmf;
 
 /* Spherical to Cartesian */
-
 	sr = sin (r2000);
 	cr = cos (r2000);
 	sd = sin (d2000);
@@ -208,7 +231,6 @@ double	rcon = 1.74532925199433e-2; /* radians per degree */
 	    }
 
 /* Convert position + velocity vector to bn system */
-
 	for (i = 0; i < 6; i++) {
 	    w = zero;
 	    for (j = 0; j < 6; j++) {
@@ -218,7 +240,6 @@ double	rcon = 1.74532925199433e-2; /* radians per degree */
 	    }
 
 /* Vector components */
-
 	x = v2[0];
 	y = v2[1];
 	z = v2[2];
@@ -227,11 +248,9 @@ double	rcon = 1.74532925199433e-2; /* radians per degree */
 	zd = v2[5];
 
 /* Magnitude of position vector */
-
 	rxyz = sqrt (x*x + y*y + z*z);
 
 /* Include e-terms */
-
 	x = x + a[0] * rxyz;
 	y = y + a[1] * rxyz;
 	z = z + a[2] * rxyz;
@@ -240,7 +259,6 @@ double	rcon = 1.74532925199433e-2; /* radians per degree */
 	zd = zd + ad[2] * rxyz;
 
 /* Convert to spherical */
-
 	rxysq = x*x + y*y;
 	rxy = sqrt (rxysq);
 
@@ -261,7 +279,6 @@ double	rcon = 1.74532925199433e-2; /* radians per degree */
 	dd1950 = ud / pmf;
 
 /* Return results */
-
 	*ra = r1950;
 	*dec = d1950;
 	*rapm = dr1950;
@@ -281,7 +298,6 @@ double	rcon = 1.74532925199433e-2; /* radians per degree */
 
 
 /* Convert B1950.0 fk4 star data to J2000.0 fk5 */
-
 static double em[6][6] = {
 	 0.999925678186902,  0.011182059571766,  0.004857946721186,
 	-0.000541652366951,  0.237917612131583, -0.436111276039270,
@@ -301,10 +317,11 @@ static double em[6][6] = {
 	-0.000000011776558, -0.000000000065874,  0.000002424101735,
 	-0.004857669684959, -0.000027184471371,  1.000009560363559};
 
-void fk425 (ra,dec)
+void
+fk425 (ra, dec)
 
-double	*ra;		/* Right ascension in radians (B1950 in, J2000 out) */
-double	*dec;		/* Declination in radians (B1950 in, J2000 out) */
+double	*ra;		/* Right ascension in degrees (B1950 in, J2000 out) */
+double	*dec;		/* Declination in degrees (B1950 in, J2000 out) */
 
 {
 double	rra;		/* Right ascension in radians (B1950 in, J2000 out) */
@@ -312,20 +329,45 @@ double	rdec;		/* Declination in radians (B1950 in, J2000 out) */
 double	rapm;		/* Proper motion in right ascension */
 double	decpm;		/* Proper motion in declination  */
 			/* In: rad/trop.yr.  Out:  rad/jul.yr. */
-double	rcon = 1.74532925199433e-2; /* radians per degree */
 void	fk425m();
 
-	rra = *ra * rcon;
-	rdec = *dec * rcon;
+	rra = degrad (*ra);
+	rdec = degrad (*dec);
 	rapm = (double) 0.0;
 	decpm = (double) 0.0;
 	fk425m (&rra, &rdec, &rapm, &decpm);
-	*ra = rra / rcon;
-	*dec = rdec / rcon;
+	*ra = raddeg (rra);
+	*dec = raddeg (rdec);
 	return;
 }
 
-void fk425m (ra, dec, rapm, decpm)
+
+void
+fk425e (ra, dec, epoch)
+
+double	*ra;		/* Right ascension in degrees (B1950 in, J2000 out) */
+double	*dec;		/* Declination in degrees (B1950 in, J2000 out) */
+double	epoch;		/* Besselian epoch in years */
+{
+double	rra;		/* Right ascension in radians (B1950 in, J2000 out) */
+double	rdec;		/* Declination in radians (B1950 in, J2000 out) */
+double	rapm;		/* Proper motion in right ascension */
+double	decpm;		/* Proper motion in declination  */
+			/* In: rad/trop.yr.  Out:  rad/jul.yr. */
+void	fk425m();
+
+	rra = degrad (*ra);
+	rdec = degrad (*dec);
+	rapm = (double) 0.0;
+	decpm = (double) 0.0;
+	fk425m (&rra, &rdec, &rapm, &decpm);
+	*ra = raddeg (rra + (rapm * (epoch - 2000.0)));
+	*dec = raddeg (rdec + (decpm * (epoch - 2000.0)));
+	return;
+}
+
+void
+fk425m (ra, dec, rapm, decpm)
 
 double	*ra, *dec;	/* Right ascension and declination in radians
 			   input:  B1950.0,fk4	returned:  J2000.0,fk5 */
@@ -397,7 +439,6 @@ double	r2000,d2000;	/* J2000.0 ra,dec (rad) */
 double	dr2000,dd2000;	/*J2000.0 proper motions (rad/jul.yr) */
 
 /* Miscellaneous */
-
 double	ur,ud,sr,cr,sd,cd,w,wd;
 double	x,y,z,xd,yd,zd, dra,ddec,rcon,scon,tcon;
 double	rxysq,rxyzsq,rxy,spxy;
@@ -416,7 +457,6 @@ double	zero = (double) 0.0;
 	pmf = 100 * 60 * 60 * 360 / d2pi;
 
 /* Pick up B1950 data (units radians and arcsec / tc) */
-
 	r1950 = *ra;
 	d1950 = *dec;
 	dr1950 = *rapm;
@@ -425,7 +465,6 @@ double	zero = (double) 0.0;
 	ud = dd1950 * pmf;
 
 /* Spherical to cartesian */
-
 	sr = sin (r1950);
 	cr = cos (r1950);
 	sd = sin (d1950);
@@ -440,7 +479,6 @@ double	zero = (double) 0.0;
 	r1[2] = 		cd*ud;
 
 /* Allow for e-terms and express as position + velocity 6-vector */
-
 	w = r0[0] * a[0] + r0[1] * a[1] + r0[2] * a[2];
 	wd = r0[0] * ad[0] + r0[1] * ad[1] + r0[2] * ad[2];
 	for (i = 0; i < 3; i++) {
@@ -449,7 +487,6 @@ double	zero = (double) 0.0;
 	    }
 
 /* Convert position + velocity vector to Fricke system */
-
 	for (i = 0; i < 6; i++) {
 	    w = zero;
 	    for (j = 0; j < 6; j++) {
@@ -459,7 +496,6 @@ double	zero = (double) 0.0;
 	    }
 
 /* Revert to spherical coordinates */
-
 	x = v2[0];
 	y = v2[1];
 	z = v2[2];
@@ -490,7 +526,6 @@ double	zero = (double) 0.0;
 	dd2000 = ud / pmf;
 
 /* Return results */
-
 	*ra = r2000;
 	*dec = d2000;
 	*rapm = dr2000;
@@ -511,17 +546,17 @@ double	zero = (double) 0.0;
 int	idg=0;
 
 /*  l2,b2 system of galactic coordinates
-/*  p = 192.25       ra of galactic north pole (mean b1950.0)
-/*  q =  62.6        inclination of galactic to mean b1950.0 equator
-/*  r =  33          longitude of ascending node
-/*  p,q,r are degrees
+ *  p = 192.25       ra of galactic north pole (mean b1950.0)
+ *  q =  62.6        inclination of galactic to mean b1950.0 equator
+ *  r =  33          longitude of ascending node
+ *  p,q,r are degrees
 
-/*  Equatorial to galactic rotation matrix
+ *  Equatorial to galactic rotation matrix
     (The Eulerian angles are p, q, 90-r)
-
-	+cp.cq.sr-sp.cr     +sp.cq.sr+cp.cr     -sq.sr
-	-cp.cq.cr-sp.sr     -sp.cq.cr+cp.sr     +sq.cr
-	cp.sq              +sp.sq              +cq */
+	+cp.cq.sr-sp.cr	+sp.cq.sr+cp.cr	-sq.sr
+	-cp.cq.cr-sp.sr	-sp.cq.cr+cp.sr	+sq.cr
+	cp.sq		+sp.sq		+cq
+ */
 
 static double bgal[3][3] = {
 	-0.066988739415,-0.872755765852,-0.483538914632,
@@ -529,8 +564,9 @@ static double bgal[3][3] = {
 	-0.867600811151,-0.188374601723, 0.460199784784};
 
 /*---  Transform b1950.0 'fk4' equatorial coordinates to
-/*     IAU 1958 galactic coordinates */
+ *     IAU 1958 galactic coordinates */
 
+void
 fk42gal (dtheta,dphi)
 
 double *dtheta;	/* b1950.0 'fk4' ra in radians
@@ -589,7 +625,8 @@ double *dphi;	/* b1950.0 'fk4' dec in radians
 /*--- Transform IAU 1958 galactic coordinates to B1950.0 'fk4'
  *    equatorial coordinates */
 
-void gal2fk4 (dtheta,dphi)
+void
+gal2fk4 (dtheta,dphi)
 
 double *dtheta;	/* Galactic longitude (l2) in radians
 		   B1950 FK4 RA in radians (returned) */
@@ -664,7 +701,8 @@ static double jgal[3][3] = {
 
 /* Transform J2000 equatorial coordinates to IAU 1958 galactic coordinates */
 
-void fk52gal (dtheta,dphi)
+void
+fk52gal (dtheta,dphi)
 
 double *dtheta;	/* J2000 right ascension in degrees
 		   Galactic longitude (l2) in degrees (returned) */
@@ -719,7 +757,8 @@ double *dphi;	/* J2000 declination in degrees
 
 /*--- Transform IAU 1958 galactic coordinates to J2000 equatorial coordinates */
 
-void gal2fk5 (dtheta,dphi)
+void
+gal2fk5 (dtheta,dphi)
 
 double *dtheta;	/* Galactic longitude (l2) in degrees
 		   J2000.0 ra in degrees (returned) */
@@ -770,7 +809,7 @@ double *dphi;	/* Galactic latitude (b2) in degrees
 }
 
 
-/* Return string with ra in hours, dec in degrees, and r in a.u. or km */
+/* Return string with right ascension in hours and declination in degrees */
 
 char *eqstrn (dra, ddec)
 
@@ -819,7 +858,8 @@ double	xpos,ypos,xp,yp,ras,decs;
 /* Convert geocentric equatorial rectangular coordinates to
    right ascension and declination, and distance */
 
-void jpcon (pos,rra,rdec,r)
+void
+jpcon (pos,rra,rdec,r)
 
 double pos[3];	/* x,y,z geocentric equatorial position of object */
 double *rra;	/* Right ascension in radians */
@@ -850,7 +890,8 @@ double *r;	/* Distance to object in same units as pos */
 /* Convert right ascension, declination, and distance to
    geocentric equatorial rectangular coordinates */
 
-void jpcop (rra,rdec,r,pos)
+void
+jpcop (rra,rdec,r,pos)
 
 double rra;	/* Right ascension in radians */
 double rdec;	/* Declination in radians */
@@ -863,6 +904,440 @@ double pos[3];	/* x,y,z geocentric equatorial position of object */
 
 	return;
 }
+
+/* The following routines are almost verbatim from Patrick Wallace's SLALIB */
+
+void
+fk4prec (ep0, ep1, ra, dec)
+
+double ep0;	/* Starting Besselian epoch */
+double ep1;	/* Ending Besselian epoch */
+double *ra;	/* RA in radians mean equator & equinox of epoch ep0
+		      mean equator & equinox of epoch ep1 (returned) */
+double *dec;	/* Dec in radians mean equator & equinox of epoch ep0
+		       mean equator & equinox of epoch ep1 (returned) */
+/*
+**  slaPreces:
+**  Precession - FK4 (Bessel-Newcomb, pre-IAU1976)
+**
+**  Note:
+**      This routine will not correctly convert between the old and
+**      the new systems - for example conversion from B1950 to J2000.
+**      For these purposes see fk425, fk524, fk45m and fk54m.
+**
+**  P.T.Wallace   Starlink   22 December 1993
+*/
+{
+    double pm[3][3], v1[3], v2[3];
+    void mprecfk4(), slaDcs2c(), slaDmxv(), slaDcc2s();
+    double slaDranrm();
+ 
+    /* Generate appropriate precession matrix */
+    mprecfk4 ( ep0, ep1, pm );
+ 
+    /* Convert RA,Dec to x,y,z */
+    slaDcs2c ( *ra, *dec, v1 );
+ 
+    /* Precess */
+    slaDmxv ( pm, v1, v2 );
+ 
+    /* Back to RA,Dec */
+    slaDcc2s ( v2, ra, dec );
+    *ra = slaDranrm ( *ra );
+}
+
+void
+fk5prec (ep0, ep1, ra, dec)
+
+double ep0;	/* Starting epoch */
+double ep1;	/* Ending epoch */
+double *ra;	/* RA in radians mean equator & equinox of epoch ep0
+		      mean equator & equinox of epoch ep1 (returned) */
+double *dec;	/* Dec in radians mean equator & equinox of epoch ep0
+		       mean equator & equinox of epoch ep1 (returned) */
+/*
+**  slaPreces:
+**  Precession -  FK5 (Fricke, post-IAU1976)
+**
+**  Note:
+**      This routine will not correctly convert between the old and
+**      the new systems - for example conversion from B1950 to J2000.
+**      For these purposes see fk425, fk524, fk45m and fk54m.
+**
+**  P.T.Wallace   Starlink   22 December 1993
+*/
+{
+    double pm[3][3], v1[3], v2[3];
+    void mprecfk5(), slaDcs2c(), slaDmxv(), slaDcc2s();
+    double slaDranrm();
+ 
+    /* Generate appropriate precession matrix */
+    mprecfk5 ( ep0, ep1, pm );
+ 
+    /* Convert RA,Dec to x,y,z */
+    slaDcs2c ( *ra, *dec, v1 );
+ 
+    /* Precess */
+    slaDmxv ( pm, v1, v2 );
+ 
+    /* Back to RA,Dec */
+    slaDcc2s ( v2, ra, dec );
+    *ra = slaDranrm ( *ra );
+}
+
+
+void
+slaDcs2c (a, b, v)
+
+double a;	/* Right ascension in radians */
+double b;	/* Declination in radians */
+double *v;	/* x,y,z unit vector (returned) */
+
+/*
+**  slaDcs2c: Spherical coordinates to direction cosines.
+**
+**  The spherical coordinates are longitude (+ve anticlockwise
+**  looking from the +ve latitude pole) and latitude.  The
+**  Cartesian coordinates are right handed, with the x axis
+**  at zero longitude and latitude, and the z axis at the
+**  +ve latitude pole.
+**
+**  P.T.Wallace   Starlink   31 October 1993
+*/
+{
+    double cosb;
+ 
+    cosb = cos ( b );
+    v[0] = cos ( a ) * cosb;
+    v[1] = sin ( a ) * cosb;
+    v[2] = sin ( b );
+}
+
+
+void
+slaDmxv (dm, va, vb)
+
+double (*dm)[3];	/* 3x3 Matrix */
+double *va;		/* Vector */
+double *vb;		/* Result vector (returned) */
+
+/*
+**  slaDmxv:
+**  Performs the 3-d forward unitary transformation:
+**     vector vb = matrix dm * vector va
+**
+**  P.T.Wallace   Starlink   31 October 1993
+*/
+{
+    int i, j;
+    double w, vw[3];
+ 
+    /* Matrix dm * vector va -> vector vw */
+    for ( j = 0; j < 3; j++ ) {
+	w = 0.0;
+	for ( i = 0; i < 3; i++ ) {
+	    w += dm[j][i] * va[i];
+	    }
+	vw[j] = w;
+	}
+ 
+    /* Vector vw -> vector vb */
+    for ( j = 0; j < 3; j++ ) {
+	vb[j] = vw[j];
+	}
+}
+
+
+void
+slaDcc2s (v, a, b)
+
+double *v;	/* x,y,z vector */
+double *a;	/* Right ascension in radians */
+double *b;	/* Declination in radians */
+
+/*
+**  slaDcc2s:
+**  Direction cosines to spherical coordinates.
+**
+**  Returned:
+**     *a,*b  double      spherical coordinates in radians
+**
+**  The spherical coordinates are longitude (+ve anticlockwise
+**  looking from the +ve latitude pole) and latitude.  The
+**  Cartesian coordinates are right handed, with the x axis
+**  at zero longitude and latitude, and the z axis at the
+**  +ve latitude pole.
+**
+**  If v is null, zero a and b are returned.
+**  At either pole, zero a is returned.
+**
+**  P.T.Wallace   Starlink   31 October 1993
+*/
+{
+    double x, y, z, r;
+ 
+    x = v[0];
+    y = v[1];
+    z = v[2];
+    r = sqrt ( x * x + y * y );
+ 
+    *a = ( r != 0.0 ) ? atan2 ( y, x ) : 0.0;
+    *b = ( z != 0.0 ) ? atan2 ( z, r ) : 0.0;
+}
+
+ 
+/* 2pi */
+#define D2PI 6.2831853071795864769252867665590057683943387987502
+
+double slaDranrm (angle)
+
+double angle;	/* angle in radians */
+
+/*
+**  slaDranrm:
+**  Normalize angle into range 0-2 pi.
+**  The result is angle expressed in the range 0-2 pi (double).
+**  Defined in slamac.h:  D2PI
+**
+**  P.T.Wallace   Starlink   30 October 1993
+*/
+{
+    double w;
+ 
+    w = fmod ( angle, D2PI );
+    return ( w >= 0.0 ) ? w : w + D2PI;
+}
+
+
+/* pi/(180*3600):  arcseconds to radians */
+#define DAS2R 4.8481368110953599358991410235794797595635330237270e-6
+
+void
+mprecfk4 (bep0, bep1, rmatp)
+
+double bep0;		/* Beginning Besselian epoch */
+double bep1;		/* Ending Besselian epoch */
+double (*rmatp)[3];	/* 3x3 Precession matrix (returned) */
+
+/*
+**  slaPrebn:
+**  Generate the matrix of precession between two epochs,
+**  using the old, pre-IAU1976, Bessel-Newcomb model, using
+**  Kinoshita's formulation (double precision)
+**
+**  The matrix is in the sense   v(bep1)  =  rmatp * v(bep0)
+**
+**  Reference:
+**     Kinoshita, H. (1975) 'Formulas for precession', SAO Special
+**     Report No. 364, Smithsonian Institution Astrophysical
+**     Observatory, Cambridge, Massachusetts.
+**
+**  P.T.Wallace   Starlink   30 October 1993
+*/
+{
+    double bigt, t, tas2r, w, zeta, z, theta;
+    void slaDeuler();
+ 
+    /* Interval between basic epoch B1850.0 and beginning epoch in TC */
+    bigt  = ( bep0 - 1850.0 ) / 100.0;
+ 
+    /* Interval over which precession required, in tropical centuries */
+    t = ( bep1 - bep0 ) / 100.0;
+ 
+    /* Euler angles */
+    tas2r = t * DAS2R;
+    w = 2303.5548 + ( 1.39720 + 0.000059 * bigt ) * bigt;
+    zeta = (w + ( 0.30242 - 0.000269 * bigt + 0.017996 * t ) * t ) * tas2r;
+    z = (w + ( 1.09478 + 0.000387 * bigt + 0.018324 * t ) * t ) * tas2r;
+    theta = ( 2005.1125 + ( - 0.85294 - 0.000365* bigt ) * bigt +
+	    ( - 0.42647 - 0.000365 * bigt - 0.041802 * t ) * t ) * tas2r;
+ 
+    /* Rotation matrix */
+    slaDeuler ( "ZYZ", -zeta, theta, -z, rmatp );
+}
+
+
+void
+mprecfk5 (ep0, ep1, rmatp)
+
+double ep0;		/* Beginning epoch */
+double ep1;		/* Ending epoch */
+double (*rmatp)[3];	/* 3x3 Precession matrix (returned) */
+
+/*
+**  slaPrec:
+**  Form the matrix of precession between two epochs (IAU 1976, FK5).
+**  Notes:
+**  1)  The epochs are TDB (loosely ET) Julian epochs.
+**  2)  The matrix is in the sense   v(ep1)  =  rmatp * v(ep0) .
+**
+**  References:
+**     Lieske,J.H., 1979. Astron. Astrophys.,73,282.
+**          equations (6) & (7), p283.
+**     Kaplan,G.H., 1981. USNO circular no. 163, pa2.
+**
+**  P.T.Wallace   Starlink   31 October 1993
+*/
+{
+    double t0, t, tas2r, w, zeta, z, theta;
+    void slaDeuler();
+ 
+    /* Interval between basic epoch J2000.0 and beginning epoch (JC) */
+    t0 = ( ep0 - 2000.0 ) / 100.0;
+ 
+    /* Interval over which precession required (JC) */
+    t =  ( ep1 - ep0 ) / 100.0;
+ 
+    /* Euler angles */
+    tas2r = t * DAS2R;
+    w = 2306.2181 + ( ( 1.39656 - ( 0.000139 * t0 ) ) * t0 );
+    zeta = (w + ( ( 0.30188 - 0.000344 * t0 ) + 0.017998 * t ) * t ) * tas2r;
+    z = (w + ( ( 1.09468 + 0.000066 * t0 ) + 0.018203 * t ) * t ) * tas2r;
+    theta = ( ( 2004.3109 + ( - 0.85330 - 0.000217 * t0 ) * t0 )
+	  + ( ( -0.42665 - 0.000217 * t0 ) - 0.041833 * t ) * t ) * tas2r;
+ 
+    /* Rotation matrix */
+    slaDeuler ( "ZYZ", -zeta, theta, -z, rmatp );
+}
+
+
+void
+slaDeuler (order, phi, theta, psi, rmat)
+
+char *order;		/* specifies about which axes the rotations occur */
+double phi;		/* 1st rotation (radians) */
+double theta;		/* 2nd rotation (radians) */
+double psi;		/* 3rd rotation (radians) */
+double (*rmat)[3];	/* 3x3 Rotation matrix (returned) */
+
+/*
+**  slaDeuler:
+**  Form a rotation matrix from the Euler angles - three successive
+**  rotations about specified Cartesian axes.
+**
+**  A rotation is positive when the reference frame rotates
+**  anticlockwise as seen looking towards the origin from the
+**  positive region of the specified axis.
+**
+**  The characters of order define which axes the three successive
+**  rotations are about.  A typical value is 'zxz', indicating that
+**  rmat is to become the direction cosine matrix corresponding to
+**  rotations of the reference frame through phi radians about the
+**  old z-axis, followed by theta radians about the resulting x-axis,
+**  then psi radians about the resulting z-axis.
+**
+**  The axis names can be any of the following, in any order or
+**  combination:  x, y, z, uppercase or lowercase, 1, 2, 3.  Normal
+**  axis labelling/numbering conventions apply;  the xyz (=123)
+**  triad is right-handed.  Thus, the 'zxz' example given above
+**  could be written 'zxz' or '313' (or even 'zxz' or '3xz').  Order
+**  is terminated by length or by the first unrecognised character.
+**
+**  Fewer than three rotations are acceptable, in which case the later
+**  angle arguments are ignored.  Zero rotations produces a unit rmat.
+**
+**  P.T.Wallace   Starlink   17 November 1993
+*/
+{
+   int j, i, l, n, k;
+   double result[3][3], rotn[3][3], angle, s, c , w, wm[3][3];
+   char axis;
+ 
+/* Initialize result matrix */
+   for ( j = 0; j < 3; j++ ) {
+      for ( i = 0; i < 3; i++ ) {
+         result[i][j] = ( i == j ) ? 1.0 : 0.0;
+      }
+   }
+ 
+/* Establish length of axis string */
+   l = strlen ( order );
+ 
+/* Look at each character of axis string until finished */
+   for ( n = 0; n < 3; n++ ) {
+      if ( n <= l ) {
+ 
+      /* Initialize rotation matrix for the current rotation */
+         for ( j = 0; j < 3; j++ ) {
+            for ( i = 0; i < 3; i++ ) {
+               rotn[i][j] = ( i == j ) ? 1.0 : 0.0;
+            }
+         }
+ 
+      /* Pick up the appropriate Euler angle and take sine & cosine */
+         switch ( n ) {
+         case 0 :
+           angle = phi;
+           break;
+         case 1 :
+           angle = theta;
+           break;
+         case 2 :
+           angle = psi;
+           break;
+         }
+         s = sin ( angle );
+         c = cos ( angle );
+ 
+      /* Identify the axis */
+         axis =  order[n];
+         if ( ( axis == 'X' ) || ( axis == 'x' ) || ( axis == '1' ) ) {
+ 
+         /* Matrix for x-rotation */
+            rotn[1][1] = c;
+            rotn[1][2] = s;
+            rotn[2][1] = -s;
+            rotn[2][2] = c;
+         }
+         else if ( ( axis == 'Y' ) || ( axis == 'y' ) || ( axis == '2' ) ) {
+ 
+         /* Matrix for y-rotation */
+            rotn[0][0] = c;
+            rotn[0][2] = -s;
+            rotn[2][0] = s;
+            rotn[2][2] = c;
+         }
+         else if ( ( axis == 'Z' ) || ( axis == 'z' ) || ( axis == '3' ) ) {
+ 
+         /* Matrix for z-rotation */
+            rotn[0][0] = c;
+            rotn[0][1] = s;
+            rotn[1][0] = -s;
+            rotn[1][1] = c;
+         } else {
+ 
+         /* Unrecognized character - fake end of string */
+            l = 0;
+         }
+ 
+      /* Apply the current rotation (matrix rotn x matrix result) */
+         for ( i = 0; i < 3; i++ ) {
+            for ( j = 0; j < 3; j++ ) {
+               w = 0.0;
+               for ( k = 0; k < 3; k++ ) {
+                  w += rotn[i][k] * result[k][j];
+               }
+               wm[i][j] = w;
+            }
+         }
+         for ( j = 0; j < 3; j++ ) {
+            for ( i= 0; i < 3; i++ ) {
+               result[i][j] = wm[i][j];
+            }
+         }
+      }
+   }
+ 
+/* Copy the result */
+   for ( j = 0; j < 3; j++ ) {
+      for ( i = 0; i < 3; i++ ) {
+         rmat[i][j] = result[i][j];
+      }
+   }
+}
 /*
  * Nov  6 1995	Include stdlib.h instead of malloc.h
+ * Apr  1 1996	Add arbitrary epoch precession
+ * Apr 26 1996	Add FK4 <-> FK5 subroutines for use when epoch is known
+ * Aug  6 1996	Clean up after lint
  */
